@@ -1,7 +1,7 @@
 package App::ValidateCPANMetaWithSah;
 
-our $DATE = '2016-07-22'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2017-01-08'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 1;
 # ABSTRACT: Validate CPAN Meta specification with Sah schema
@@ -18,7 +18,7 @@ App::ValidateCPANMetaWithSah - Validate CPAN Meta specification with Sah schema
 
 =head1 VERSION
 
-This document describes version 0.001 of App::ValidateCPANMetaWithSah (from Perl distribution App-ValidateCPANMetaWithSah), released on 2016-07-22.
+This document describes version 0.002 of App::ValidateCPANMetaWithSah (from Perl distribution App-ValidateCPANMetaWithSah), released on 2017-01-08.
 
 =head1 SYNOPSIS
 
@@ -45,13 +45,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<CPAN::Meta>, L<CPAN::Meta::Validator>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
